#
# spec file for package python-Shapely
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without test

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-Shapely
Version:        1.5.17
Release:        23.1
Summary:        Geospatial geometries, predicates, and operations
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Url:            http://pypi.python.org/pypi/Shapely
Source:         https://files.pythonhosted.org/packages/source/S/Shapely/Shapely-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 0.19}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  geos-devel >= 3.3
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
%if 0%{?suse_version} > 1320
BuildRequires:  %{python_module matplotlib}
%endif
%endif
Requires:       geos >= 3.3
%ifpython2
Obsoletes:      %{oldpython}-shapely < %{version}
Provides:       %{oldpython}-shapely = %{version}
%endif
%ifpython3
Obsoletes:      python3-shapely < %{version}
Provides:       python3-shapely = %{version}
%endif
%python_subpackages

%description
Shapely is a Python package for manipulation and analysis of
planar geometric objects. It is based on the GEOS (the
engine of PostGIS) and JTS (from which GEOS is ported) libraries.
Shapely is not concerned with data formats or coordinate systems,
but can be readily integrated with packages that are like WorldMill
and pyproj.

%prep
%setup -q -n Shapely-%{version}

%build
CFLAGS="%{optflags} `geos-config --cflags` LDFLAGS=`geos-config --clibs`"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

# Those are just needed to build cython extension
# Not for distribute
rm -fv %{buildroot}%{_prefix}/shapely/_geos.pxi
rm -frv %{buildroot}%{_prefix}/shapely

%if %{with test}
%check
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc CREDITS.txt LICENSE.txt README.rst docs/*
%{python_sitearch}/*

%changelog
* Wed Jul 12 2017 toddrme2178@gmail.com
- Don't require ctypes, it is built-in.
- Fix backwards-compatibility provides.
* Wed Jul 12 2017 jengelh@inai.de
- Remove redundant wording from description.
* Tue Jul 11 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Fix source URL.
- Update to 1.5.17
  * Bug fix: eliminate memory leak in geom_factory() (#408).
  * Bug fix: remove mention of negative distances in parallel_offset and note
    that vertices of right hand offset lines are reversed (#284).
- Update to 1.5.16
  * Bug fix: eliminate memory leak when unpickling geometry objects (#384, #385).
  * Bug fix: prevent crashes when attempting to pickle a prepared geometry,
    raising ``PicklingError`` instead (#386).
  * Packaging: extension modules in the OS X wheels uploaded to PyPI link only
    libgeos_c.dylib now (you can verify and compare to previous releases with
    ``otool -L shapely/vectorized/_vectorized.so``).
- Update to 1.5.15
  * Bug fix: use uintptr_t to store pointers instead of long in _geos.pxi,
    preventing an overflow error (#372, #373). Note that this bug fix was
    erroneously reported to have been made in 1.5.14, but was not.
- Update to 1.5.14
  * Bug fix: use ``type()`` instead of ``isinstance()`` when evaluating geometry
    equality, preventing instances of base and derived classes from
    being mistaken for equals (#317).
  * Bug fix: ensure that empty geometries are created when constructors have no
    args (#332, #333).
  * Bug fix: support app "freezing" better on Windows by not relying on the
  ``__file__`` attribute (#342, #377).
  * Bug fix: ensure that empty polygons evaluate to be ``==`` (#355).
  * Bug fix: filter out empty geometries that can cause segfaults when creating
    and loading STRtrees (#345, #348).
  * Bug fix: no longer attempt to reuse GEOS DLLs already loaded by Rasterio
    or Fiona on OS X (#374, #375).
- Update to 1.5.13
  * Restore setup and runtime discovery and loading of GEOS shared library to
    state at version 1.5.9 (#326).
  * On OS X we try to reuse any GEOS shared library that may have been loaded
    via import of Fiona or Rasterio in order to avoid a bug involving the
    GEOS AbstractSTRtree (#324, #327).
- Update to 1.5.12
  * Remove configuration of root logger from libgeos.py (#312).
  * Skip test_fallbacks on Windows (#308).
  * Call setlocale(locale.LC_ALL, "") instead of resetlocale() on Windows when
    tearing down the locale test (#308).
  * Fix for Sphinx warnings (#309).
  * Addition of .cache, .idea, .pyd, .pdb to .gitignore (#310).
- Update to 1.5.11
  * Remove packaging module requirement added in 1.5.10 (#305). Distutils can't
    parse versions using 'rc', but if we stick to 'a' and 'b' we will be fine.
- Update to 1.5.10
  * Monkey patch affinity module by absolute reference (#299).
  * Raise TopologicalError in relate() instead of crashing (#294, #295, #303).
* Mon Jun 15 2015 bruno@ioda-net.ch
- Update to 1.5.9
  * Fix for 64 bit speedups compatibility (#274).
* Sun May 24 2015 bruno@ioda-net.ch
- Packaging
  * Added Provides lowercase
  * Added BuildRequire geos-devel Require geos
  * Added python-Cytools to build c extension
* Sun May 24 2015 bruno@ioda-net.ch
- Update to version 1.5.8 (2015-04-29)
  * Setup file encoding bug fix (#254).
  * Support for pyinstaller (#261).
  * Major prepared geometry operation fix for Windows (#268, #269).
  * Major fix for OS X binary wheel (#262).
- Changes since 1.2.18
  1.5.7 (2015-03-16)
    Test and fix buggy error and notice handlers (#249).
  1.5.6 (2015-02-02)
    Fix setup regression (#232, #234).
    SVG representation improvements (#233, #237).
  1.5.5 (2015-01-20)
    MANIFEST changes to restore _geox.pxi (#231).
  1.5.4 (2015-01-19)
    Fixed OS X binary wheel library load path (#224).
  1.5.3 (2015-01-12)
    Fixed ownership and potential memory leak in polygonize (#223).
    Wider release of binary wheels for OS X.
  1.5.2 (2015-01-04)
    Fail installation if GEOS dependency is not met, preventing update breakage (#218, #219).
  1.5.1 (2014-12-04)
    Restore geometry hashing (#209).
  1.5.0 (2014-12-02)
    Affine transformation speedups (#197).
    New == rich comparison (#195).
    Geometry collection constructor (#200).
    ops.snap() backed by GEOSSnap (#201).
    Clearer exceptions in cases of topological invalidity (#203).
  1.4.4 (2014-11-02)
    Proper conversion of numpy float32 vals to coords (#186).
  1.4.3 (2014-10-01)
    Fix for endianness bug in WKB writer (#174).
  1.4.2 (2014-09-29)
    Fix bungled 1.4.1 release (#176).
  1.4.1 (2014-09-23)
    Return of support for GEOS 3.2 (#176, #178).
  1.4.0 (2014-09-08)
    SVG representations for IPython’s inline image protocol.
    Efficient and fast vectorized contains().
    Change mitre_limit default to 5.0; raise ValueError with 0.0 (#139).
    Allow mix of tuples and Points in sped-up LineString ctor (#152).
    New STRtree class (#73).
    Add ops.nearest_points() (#147).
    Faster creation of geometric objects from others (cloning) (#165).
    Removal of tests from package.
  1.3.3 (2014-07-23)
    Allow single-part geometries as argument to ops.cacaded_union() (#135).
    Support affine transformations of LinearRings (#112).
  1.3.2 (2014-05-13)
    Let LineString() take a sequence of Points (#130).
  1.3.1 (2014-04-22)
    More reliable proxy cleanup on exit (#106).
    More robust DLL loading on all platforms (#114).
  1.3.0 (2013-12-31)
    Include support for Python 3.2 and 3.3 (#56), minimum version is now 2.6.
    Switch to GEOS WKT/WKB Reader/Writer API, with defaults changed to enable 3D output dimensions, and to ‘trim’ WKT output for GEOS >=3.3.0.
    Use GEOS version instead of GEOS C API version to determine library capabilities (#65).
  1.2.19 (2013-12-30)
    Add buffering style options (#55).
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Sep 25 2013 p.drouand@gmail.com
- Update to version 1.2.18
  + Add shapely.ops.transform.
  + Permit empty sequences in collection constructors (#49, #50).
  + Individual polygons in MultiPolygon.__geo_interface__ are changed
    to tuples to match Polygon.__geo_interface__ (#51).
  + Add shapely.ops.polygonize_full (#57).
- Changes between 1.2.17 and 1.2.16
  + Avoid circular import between wkt/wkb and geometry.base by moving calls
    to GEOS serializers to the latter module.
  + Set _ndim when unpickling (issue #6).
  + Don't install DLLs to Python's DLL directory (#37).
  + Add affinity module of affine transformation (#31).
  + Fix NameError that blocked installation with PyPy (#40, #41).
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 1.2.16:
  + Add ops.unary_union function.
  + Alias ops.cascaded_union to ops.unary_union when GEOS CAPI >= (1,7,0).
  + Add geos_version_string attribute to shapely.geos.
  + Ensure parent is set when child geometry is accessed.
  + Generate _speedups.c using Cython when building from repo when missing,
    stale, or the build target is "sdist".
  + The is_simple predicate of invalid, self-intersecting linear rings now
    returns ``False``.
  + Remove VERSION.txt from repo, it's now written by the distutils setup script
    with value of shapely.__version__.
- Changes from version 1.2.15:
  + Eliminate numerical sensitivity in a method chaining test (Debian bug
    [#663210]).
  + Account for cascaded union of random buffered test points being a polygon
    or multipolygon (Debian bug #666655).
  + Use Cython to build speedups if it is installed.
  + Avoid stumbling over SVN revision numbers in GEOS C API version strings.
* Thu Feb 23 2012 saschpe@suse.de
- Update to version 1.2.14:
  + A geometry's coords property is now sliceable, yielding a list of coordinate
    values.
  + Homogeneous collections are now sliceable, yielding a new collection of the
    same type.
* Thu Dec 15 2011 saschpe@suse.de
- Minor spec file cleanup:
  * Ran spec-cleaner
  * Use original tarball
  * Don't use --record-rpm (only SUSE)
  sc
* Thu Dec 15 2011 j.verdoold@gmail.com
- Updated to 1.2.13
* Wed Sep 30 2009 cfarrell1980@gmail.com
- Updated to 1.0.13
* Thu May 28 2009 cfarrell1980@gmail.com
- Initial import
